@@ -34,9 +34,11 @@ __all__ = (
     "DeleteGatewayInputRequestTypeDef",
     "DeleteHypervisorInputRequestTypeDef",
     "DisassociateGatewayFromServerInputRequestTypeDef",
-    "GatewayDetailsTypeDef",
+    "MaintenanceStartTimeTypeDef",
     "GatewayTypeDef",
     "GetGatewayInputRequestTypeDef",
+    "GetVirtualMachineInputRequestTypeDef",
+    "VirtualMachineDetailsTypeDef",
     "HypervisorTypeDef",
     "PaginatorConfigTypeDef",
     "ListGatewaysInputRequestTypeDef",
@@ -66,13 +68,15 @@ __all__ = (
     "ImportHypervisorConfigurationInputRequestTypeDef",
     "ListTagsForResourceOutputTypeDef",
     "TagResourceInputRequestTypeDef",
-    "GetGatewayOutputTypeDef",
+    "GatewayDetailsTypeDef",
     "ListGatewaysOutputTypeDef",
+    "GetVirtualMachineOutputTypeDef",
     "ListHypervisorsOutputTypeDef",
     "ListGatewaysInputListGatewaysPaginateTypeDef",
     "ListHypervisorsInputListHypervisorsPaginateTypeDef",
     "ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef",
     "ListVirtualMachinesOutputTypeDef",
+    "GetGatewayOutputTypeDef",
 )
 
 AssociateGatewayToServerInputRequestTypeDef = TypedDict(
@@ -123,20 +127,29 @@ DisassociateGatewayFromServerInputRequestTypeDef = TypedDict(
     },
 )
 
-GatewayDetailsTypeDef = TypedDict(
-    "GatewayDetailsTypeDef",
+_RequiredMaintenanceStartTimeTypeDef = TypedDict(
+    "_RequiredMaintenanceStartTimeTypeDef",
     {
-        "GatewayArn": str,
-        "GatewayDisplayName": str,
-        "GatewayType": Literal["BACKUP_VM"],
-        "HypervisorId": str,
-        "LastSeenTime": datetime,
-        "NextUpdateAvailabilityTime": datetime,
-        "VpcEndpoint": str,
+        "HourOfDay": int,
+        "MinuteOfHour": int,
+    },
+)
+_OptionalMaintenanceStartTimeTypeDef = TypedDict(
+    "_OptionalMaintenanceStartTimeTypeDef",
+    {
+        "DayOfMonth": int,
+        "DayOfWeek": int,
     },
     total=False,
 )
 
+
+class MaintenanceStartTimeTypeDef(
+    _RequiredMaintenanceStartTimeTypeDef, _OptionalMaintenanceStartTimeTypeDef
+):
+    pass
+
+
 GatewayTypeDef = TypedDict(
     "GatewayTypeDef",
     {
@@ -156,6 +169,26 @@ GetGatewayInputRequestTypeDef = TypedDict(
     },
 )
 
+GetVirtualMachineInputRequestTypeDef = TypedDict(
+    "GetVirtualMachineInputRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+VirtualMachineDetailsTypeDef = TypedDict(
+    "VirtualMachineDetailsTypeDef",
+    {
+        "HostName": str,
+        "HypervisorId": str,
+        "LastBackupDate": datetime,
+        "Name": str,
+        "Path": str,
+        "ResourceArn": str,
+    },
+    total=False,
+)
+
 HypervisorTypeDef = TypedDict(
     "HypervisorTypeDef",
     {
@@ -206,6 +239,7 @@ ListTagsForResourceInputRequestTypeDef = TypedDict(
 ListVirtualMachinesInputRequestTypeDef = TypedDict(
     "ListVirtualMachinesInputRequestTypeDef",
     {
+        "HypervisorArn": str,
         "MaxResults": int,
         "NextToken": str,
     },
@@ -497,12 +531,19 @@ TagResourceInputRequestTypeDef = TypedDict(
     },
 )
 
-GetGatewayOutputTypeDef = TypedDict(
-    "GetGatewayOutputTypeDef",
+GatewayDetailsTypeDef = TypedDict(
+    "GatewayDetailsTypeDef",
     {
-        "Gateway": GatewayDetailsTypeDef,
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "GatewayArn": str,
+        "GatewayDisplayName": str,
+        "GatewayType": Literal["BACKUP_VM"],
+        "HypervisorId": str,
+        "LastSeenTime": datetime,
+        "MaintenanceStartTime": MaintenanceStartTimeTypeDef,
+        "NextUpdateAvailabilityTime": datetime,
+        "VpcEndpoint": str,
     },
+    total=False,
 )
 
 ListGatewaysOutputTypeDef = TypedDict(
@@ -514,6 +555,14 @@ ListGatewaysOutputTypeDef = TypedDict(
     },
 )
 
+GetVirtualMachineOutputTypeDef = TypedDict(
+    "GetVirtualMachineOutputTypeDef",
+    {
+        "VirtualMachine": VirtualMachineDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListHypervisorsOutputTypeDef = TypedDict(
     "ListHypervisorsOutputTypeDef",
     {
@@ -542,6 +591,7 @@ ListHypervisorsInputListHypervisorsPaginateTypeDef = TypedDict(
 ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef = TypedDict(
     "ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef",
     {
+        "HypervisorArn": str,
         "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
@@ -555,3 +605,11 @@ ListVirtualMachinesOutputTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+GetGatewayOutputTypeDef = TypedDict(
+    "GetGatewayOutputTypeDef",
+    {
+        "Gateway": GatewayDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
